@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -291,7 +291,7 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
         def __hash__(self):
             return hash("ComputeThreatListDiff")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "threatType": {},
             "constraints": {},
         }
@@ -382,7 +382,7 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
         def __hash__(self):
             return hash("CreateSubmission")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -406,7 +406,6 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
                 request (~.webrisk.CreateSubmissionRequest):
                     The request object. Request to send a potentially phishy
                 URI to WebRisk.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -483,7 +482,7 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
         def __hash__(self):
             return hash("SearchHashes")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "threatTypes": {},
         }
 
@@ -509,7 +508,6 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
                 request (~.webrisk.SearchHashesRequest):
                     The request object. Request to return full hashes matched
                 by the provided hash prefixes.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -573,7 +571,7 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
         def __hash__(self):
             return hash("SearchUris")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "uri": "",
             "threatTypes": {},
         }
@@ -600,7 +598,6 @@ class WebRiskServiceRestTransport(WebRiskServiceTransport):
                 request (~.webrisk.SearchUrisRequest):
                     The request object. Request to check URI entries against
                 threatLists.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
