@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -260,7 +260,7 @@ class WebRiskServiceV1Beta1RestTransport(WebRiskServiceV1Beta1Transport):
         def __hash__(self):
             return hash("ComputeThreatListDiff")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "threatType": {},
             "constraints": {},
         }
@@ -351,7 +351,7 @@ class WebRiskServiceV1Beta1RestTransport(WebRiskServiceV1Beta1Transport):
         def __hash__(self):
             return hash("SearchHashes")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "threatTypes": {},
         }
 
@@ -377,7 +377,6 @@ class WebRiskServiceV1Beta1RestTransport(WebRiskServiceV1Beta1Transport):
                 request (~.webrisk.SearchHashesRequest):
                     The request object. Request to return full hashes matched
                 by the provided hash prefixes.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -441,7 +440,7 @@ class WebRiskServiceV1Beta1RestTransport(WebRiskServiceV1Beta1Transport):
         def __hash__(self):
             return hash("SearchUris")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "uri": "",
             "threatTypes": {},
         }
@@ -468,7 +467,6 @@ class WebRiskServiceV1Beta1RestTransport(WebRiskServiceV1Beta1Transport):
                 request (~.webrisk.SearchUrisRequest):
                     The request object. Request to check URI entries against
                 threatLists.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
